==> haskell-yesod-persistent-1.4.0.3-25-armv7h.pkg.tar.xz: usr/share/haskell/haskell-yesod-persistent/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-persistent
version: 1.4.0.3
id: yesod-persistent-1.4.0.3-ca84b6eb145e15f51b714d496323d807
key: yesod_5eiPdZomF2R7e8roJwl0qE
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Some helpers for using Persistent from Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-persistent>
category: Web, Yesod, Database
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod.Persist Yesod.Persist.Core
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-persistent-1.4.0.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-persistent-1.4.0.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-persistent-1.4.0.3
hs-libraries: HSyesod-persistent-1.4.0.3-5eiPdZomF2R7e8roJwl0qE
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
    persistent-2.2.4.1-550ce3a441e5dfee4f5236d6597d598b
    persistent-template-2.1.6-abb9add555d6012706d07d6768084389
    resource-pool-0.2.3.2-43a43754061092f307f80bb6d2ee434f
    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    yesod-core-1.4.19-42832ae56c3d48408d8da65a0e354ab2
haddock-interfaces: /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock
haddock-html: /usr/share/doc/haskell-yesod-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-persistent-1.4.0.4-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-yesod-persistent/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-persistent
version: 1.4.0.4
id: yesod-persistent-1.4.0.4-a374b45e8b618c21d99c5a049b52b954
key: yesod_CvtMXv7beWE5VUzjiaZTRu
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Some helpers for using Persistent from Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-persistent>
category: Web, Yesod, Database
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod.Persist Yesod.Persist.Core
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-persistent-1.4.0.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-persistent-1.4.0.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-persistent-1.4.0.4
hs-libraries: HSyesod-persistent-1.4.0.4-CvtMXv7beWE5VUzjiaZTRu
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
    persistent-2.2.4.1-f7f5136d623755022a88522f150cf471
    persistent-template-2.1.6-696af2309e8b2b7d269b843dd09030c3
    resource-pool-0.2.3.2-1d704fbdc1706c3584f9663671e9b735
    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    yesod-core-1.4.20-a64b314810952b5a1be9638e42c84862
haddock-interfaces: /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock
haddock-html: /usr/share/doc/haskell-yesod-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
